AuthStatus enum
Result of an authentication process.
Values
- ok → const AuthStatus
-
The authentication was succesfull.
- incorrectCredentials → const AuthStatus
-
The authentication failed because the request was rejected by the server.
- tooManyOtpRequests → const AuthStatus
- serverError → const AuthStatus
-
The authentication failed because the server could not be reached or had an internal error.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
AuthStatus> - A constant List of the values in this enum, in order of their declaration.